@@ -5,7 +5,6 @@ import (
 	"container/list"
 	"io"
 	"os"
-	"path/filepath"
 
 	yaml "gopkg.in/yaml.v3"
 )
@@ -14,7 +13,9 @@ func readStream(filename string) (io.Reader, error) {
 	if filename == "-" {
 		return bufio.NewReader(os.Stdin), nil
 	} else {
-		return os.Open(filepath.Clean(filename))
+		// ignore CWE-22 gosec issue - that's more targetted for http based apps that run in a public directory,
+		// and ensuring that it's not possible to give a path to a file outside thar directory.
+		return os.Open(filename) // #nosec
 	}
 }
 
